Set routines
============

.. currentmodule:: numpy

Making proper sets
------------------
.. autosummary::
   :toctree: generated/

   unique
   unique_all
   unique_counts
   unique_inverse
   unique_values

Boolean operations
------------------
.. autosummary::
   :toctree: generated/

   intersect1d
   isin
   setdiff1d
   setxor1d
   union1d
